@@ -11,8 +11,9 @@ import numpy as np
 import pandas as pd
 from tqdm import tqdm
 import pickle
+import fire
 
-from deepface.basemodels import VGGFace, OpenFace, Facenet, Facenet512, FbDeepFace, DeepID, DlibWrapper, ArcFace, Boosting
+from deepface.basemodels import VGGFace, OpenFace, Facenet, Facenet512, FbDeepFace, DeepID, DlibWrapper, ArcFace, Boosting, SFaceWrapper
 from deepface.extendedmodels import Age, Gender, Race, Emotion
 from deepface.commons import functions, realtime, distance as dst
 
@@ -46,6 +47,7 @@ def build_model(model_name):
 		'DeepID': DeepID.loadModel,
 		'Dlib': DlibWrapper.loadModel,
 		'ArcFace': ArcFace.loadModel,
+		'SFace': SFaceWrapper.load_model,
 		'Emotion': Emotion.loadModel,
 		'Age': Age.loadModel,
 		'Gender': Gender.loadModel,
@@ -72,7 +74,7 @@ def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric =
 	This function verifies an image pair is same person or different persons.
 
 	Parameters:
-		img1_path, img2_path: exact image path, numpy array or based64 encoded images could be passed. If you are going to call verify function for a list of image pairs, then you should pass an array instead of calling the function in for loops.
+		img1_path, img2_path: exact image path, numpy array (BGR) or based64 encoded images could be passed. If you are going to call verify function for a list of image pairs, then you should pass an array instead of calling the function in for loops.
 
 		e.g. img1_path = [
 			['img1.jpg', 'img2.jpg'],
@@ -270,7 +272,7 @@ def analyze(img_path, actions = ('emotion', 'age', 'gender', 'race') , models =
 	This function analyzes facial attributes including age, gender, emotion and race
 
 	Parameters:
-		img_path: exact image path, numpy array or base64 encoded image could be passed. If you are going to analyze lots of images, then set this to list. e.g. img_path = ['img1.jpg', 'img2.jpg']
+		img_path: exact image path, numpy array (BGR) or base64 encoded image could be passed. If you are going to analyze lots of images, then set this to list. e.g. img_path = ['img1.jpg', 'img2.jpg']
 
 		actions (tuple): The default is ('age', 'gender', 'emotion', 'race'). You can drop some of those attributes.
 
@@ -280,7 +282,7 @@ def analyze(img_path, actions = ('emotion', 'age', 'gender', 'race') , models =
 			models['age'] = DeepFace.build_model('Age')
 			models['gender'] = DeepFace.build_model('Gender')
 			models['emotion'] = DeepFace.build_model('Emotion')
-			models['race'] = DeepFace.build_model('race')
+			models['race'] = DeepFace.build_model('Race')
 
 		enforce_detection (boolean): The function throws exception if a face could not be detected. Set this to True if you don't want to get exception. This might be convenient for low resolution images.
 
@@ -466,13 +468,13 @@ def analyze(img_path, actions = ('emotion', 'age', 'gender', 'race') , models =
 
 		return resp_obj
 
-def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, prog_bar = True, normalization = 'base'):
+def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, prog_bar = True, normalization = 'base', silent=False):
 
 	"""
 	This function applies verification several times and find an identity in a database
 
 	Parameters:
-		img_path: exact image path, numpy array or based64 encoded image. If you are going to find several identities, then you should pass img_path as array instead of calling find function in a for loop. e.g. img_path = ["img1.jpg", "img2.jpg"]
+		img_path: exact image path, numpy array (BGR) or based64 encoded image. If you are going to find several identities, then you should pass img_path as array instead of calling find function in a for loop. e.g. img_path = ["img1.jpg", "img2.jpg"]
 
 		db_path (string): You should store some .jpg files in a folder and pass the exact folder path to this.
 
@@ -505,7 +507,7 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 		if model == None:
 
 			if model_name == 'Ensemble':
-				print("Ensemble learning enabled")
+				if not silent: print("Ensemble learning enabled")
 				models = Boosting.loadModel()
 
 			else: #model is not ensemble
@@ -514,7 +516,7 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 				models[model_name] = model
 
 		else: #model != None
-			print("Already built model is passed")
+			if not silent: print("Already built model is passed")
 
 			if model_name == 'Ensemble':
 				Boosting.validate_model(model)
@@ -540,12 +542,12 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 
 		if path.exists(db_path+"/"+file_name):
 
-			print("WARNING: Representations for images in ",db_path," folder were previously stored in ", file_name, ". If you added new instances after this file creation, then please delete this file and call find function again. It will create it again.")
+			if not silent: print("WARNING: Representations for images in ",db_path," folder were previously stored in ", file_name, ". If you added new instances after this file creation, then please delete this file and call find function again. It will create it again.")
 
 			f = open(db_path+'/'+file_name, 'rb')
 			representations = pickle.load(f)
 
-			print("There are ", len(representations)," representations found in ",file_name)
+			if not silent: print("There are ", len(representations)," representations found in ",file_name)
 
 		else: #create representation.pkl from scratch
 			employees = []
@@ -593,7 +595,7 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 			pickle.dump(representations, f)
 			f.close()
 
-			print("Representations stored in ",db_path,"/",file_name," file. Please delete this file when you add new identities in your database.")
+			if not silent: print("Representations stored in ",db_path,"/",file_name," file. Please delete this file when you add new identities in your database.")
 
 		#----------------------------
 		#now, we got representations for facial database
@@ -704,7 +706,7 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 
 		toc = time.time()
 
-		print("find function lasts ",toc-tic," seconds")
+		if not silent: print("find function lasts ",toc-tic," seconds")
 
 		if len(resp_obj) == 1:
 			return resp_obj[0]
@@ -722,7 +724,7 @@ def represent(img_path, model_name = 'VGG-Face', model = None, enforce_detection
 	This function represents facial images as vectors.
 
 	Parameters:
-		img_path: exact image path, numpy array or based64 encoded images could be passed.
+		img_path: exact image path, numpy array (BGR) or based64 encoded images could be passed.
 
 		model_name (string): VGG-Face, Facenet, OpenFace, DeepFace, DeepID, Dlib, ArcFace.
 
@@ -806,7 +808,7 @@ def detectFace(img_path, target_size = (224, 224), detector_backend = 'opencv',
 	This function applies pre-processing stages of a face recognition pipeline including detection and alignment
 
 	Parameters:
-		img_path: exact image path, numpy array or base64 encoded image
+		img_path: exact image path, numpy array (BGR) or base64 encoded image
 
 		detector_backend (string): face detection backends are retinaface, mtcnn, opencv, ssd or dlib
 
@@ -822,3 +824,6 @@ def detectFace(img_path, target_size = (224, 224), detector_backend = 'opencv',
 #main
 
 functions.initialize_folder()
+
+def cli():
+	fire.Fire()
