@@ -4,6 +4,8 @@ import pandas as pd
 import cv2
 import base64
 from pathlib import Path
+from PIL import Image
+import requests
 
 from deepface.detectors import FaceDetector
 
@@ -43,17 +45,19 @@ def initialize_input(img1_path, img2_path = None):
 
 	return img_list, bulkProcess
 
-def initializeFolder():
-
-	home = str(Path.home())
+def initialize_folder():
+	home = get_deepface_home()
 
 	if not os.path.exists(home+"/.deepface"):
-		os.mkdir(home+"/.deepface")
-		print("Directory ",home,"/.deepface created")
+		os.makedirs(home+"/.deepface")
+		print("Directory ", home, "/.deepface created")
 
 	if not os.path.exists(home+"/.deepface/weights"):
-		os.mkdir(home+"/.deepface/weights")
-		print("Directory ",home,"/.deepface/weights created")
+		os.makedirs(home+"/.deepface/weights")
+		print("Directory ", home, "/.deepface/weights created")
+
+def get_deepface_home():
+	return str(os.getenv('DEEPFACE_HOME', default=Path.home()))
 
 def loadBase64Img(uri):
    encoded_data = uri.split(',')[1]
@@ -62,20 +66,25 @@ def loadBase64Img(uri):
    return img
 
 def load_image(img):
+	exact_image = False; base64_img = False; url_img = False
 
-	exact_image = False
 	if type(img).__module__ == np.__name__:
 		exact_image = True
 
-	base64_img = False
-	if len(img) > 11 and img[0:11] == "data:image/":
+	elif len(img) > 11 and img[0:11] == "data:image/":
 		base64_img = True
 
+	elif len(img) > 11 and img.startswith("http"):
+		url_img = True
+
 	#---------------------------
 
 	if base64_img == True:
 		img = loadBase64Img(img)
 
+	elif url_img:
+		img = np.array(Image.open(requests.get(img, stream=True).raw))
+
 	elif exact_image != True: #image path passed as input
 		if os.path.isfile(img) != True:
 			raise ValueError("Confirm that ",img," exists")
@@ -88,21 +97,31 @@ def detect_face(img, detector_backend = 'opencv', grayscale = False, enforce_det
 
 	img_region = [0, 0, img.shape[0], img.shape[1]]
 
+	#----------------------------------------------
+	#people would like to skip detection and alignment if they already have pre-processed images
+	if detector_backend == 'skip':
+		return img, img_region
+
+	#----------------------------------------------
+
 	#detector stored in a global variable in FaceDetector object.
 	#this call should be completed very fast because it will return found in memory
 	#it will not build face detector model in each call (consider for loops)
 	face_detector = FaceDetector.build_model(detector_backend)
 
-	detected_face, img_region = FaceDetector.detect_face(face_detector, detector_backend, img, align)
+	try:
+		detected_face, img_region = FaceDetector.detect_face(face_detector, detector_backend, img, align)
+	except: #if detected face shape is (0, 0) and alignment cannot be performed, this block will be run
+		detected_face = None
 
 	if (isinstance(detected_face, np.ndarray)):
 		return detected_face, img_region
 	else:
 		if detected_face == None:
 			if enforce_detection != True:
-			  return img, img_region
+				return img, img_region
 			else:
-			  raise ValueError("Face could not be detected. Please confirm that the picture is a face photo or consider to set enforce_detection param to False.")
+				raise ValueError("Face could not be detected. Please confirm that the picture is a face photo or consider to set enforce_detection param to False.")
 
 def normalize_input(img, normalization = 'base'):
 
@@ -177,21 +196,24 @@ def preprocess_face(img, target_size=(224, 224), grayscale = False, enforce_dete
 
 	# img = cv2.resize(img, target_size) #resize causes transformation on base image, adding black pixels to resize will not deform the base image
 
-	factor_0 = target_size[0] / img.shape[0]
-	factor_1 = target_size[1] / img.shape[1]
-	factor = min(factor_0, factor_1)
+	if img.shape[0] > 0 and img.shape[1] > 0:
+		factor_0 = target_size[0] / img.shape[0]
+		factor_1 = target_size[1] / img.shape[1]
+		factor = min(factor_0, factor_1)
 
-	dsize = (int(img.shape[1] * factor), int(img.shape[0] * factor))
-	img = cv2.resize(img, dsize)
+		dsize = (int(img.shape[1] * factor), int(img.shape[0] * factor))
+		img = cv2.resize(img, dsize)
 
-	# Then pad the other side to the target size by adding black pixels
-	diff_0 = target_size[0] - img.shape[0]
-	diff_1 = target_size[1] - img.shape[1]
-	if grayscale == False:
-		# Put the base image in the middle of the padded image
-		img = np.pad(img, ((diff_0 // 2, diff_0 - diff_0 // 2), (diff_1 // 2, diff_1 - diff_1 // 2), (0, 0)), 'constant')
-	else:
-		img = np.pad(img, ((diff_0 // 2, diff_0 - diff_0 // 2), (diff_1 // 2, diff_1 - diff_1 // 2)), 'constant')
+		# Then pad the other side to the target size by adding black pixels
+		diff_0 = target_size[0] - img.shape[0]
+		diff_1 = target_size[1] - img.shape[1]
+		if grayscale == False:
+			# Put the base image in the middle of the padded image
+			img = np.pad(img, ((diff_0 // 2, diff_0 - diff_0 // 2), (diff_1 // 2, diff_1 - diff_1 // 2), (0, 0)), 'constant')
+		else:
+			img = np.pad(img, ((diff_0 // 2, diff_0 - diff_0 // 2), (diff_1 // 2, diff_1 - diff_1 // 2)), 'constant')
+
+	#------------------------------------------
 
 	#double check: if target image is not still the same size with target.
 	if img.shape[0:2] != target_size:
